@@ -51,7 +51,7 @@ def process_string(text,
     elif numbers == 'remove':
         text = re.sub('[0-9]+', ' ', text)
     if remove_punctuation:
-        text = re.sub('[^A-Za-z\s]', ' ', text)
+        text = re.sub(r'[^\sA-Za-z0-9À-ÖØ-öø-ÿЀ-ӿ/]', ' ', text)
     if remove_stop_words:
         text = ' '.join([word for word in text.split() if word not in stop_words + stop_words_extra])
     if remove_short_words:
@@ -92,11 +92,15 @@ def import_data(path_to_mallet,
                 path_to_training_data,
                 path_to_formatted_training_data,
                 training_data,
+                training_ids=None,
                 use_pipe_from=None):
 
     training_data_file = open(path_to_training_data, 'w')
     for i, d in enumerate(training_data):
-        training_data_file.write(str(i) + ' ' + str(i) + ' ' + d + '\n')
+        if training_ids:
+            training_data_file.write(str(training_ids[i]) + ' no_label ' + d + '\n')
+        else:
+            training_data_file.write(str(i) + ' no_label ' + d + '\n')
     training_data_file.close()
 
     if use_pipe_from:
@@ -142,12 +146,21 @@ def load_topic_distributions(topic_distributions_path):
     topic_distributions = []
     for line in open(topic_distributions_path, 'r'):
         if line.split()[0] != '#doc':
-            index, distribution = (line.split('\t')[1], line.split('\t')[2:])
+            instance_id, distribution = (line.split('\t')[1], line.split('\t')[2:])
             distribution = [float(p) for p in distribution]
             topic_distributions.append(distribution)
     return topic_distributions
 
 
+def load_training_ids(topic_distributions_path):
+    training_ids = []
+    for line in open(topic_distributions_path, 'r'):
+        if line.split()[0] != '#doc':
+            instance_id, distribution = (line.split('\t')[1], line.split('\t')[2:])
+            training_ids.append(instance_id)
+    return training_ids
+
+
 def get_top_docs(training_data, topic_distributions, topic_index, n=5):
     sorted_data = sorted([(_distribution[topic_index], _document) 
                           for _distribution, _document 
@@ -169,7 +182,7 @@ def plot_categories_by_topics_heatmap(labels,
             for _topic_index, _probability in enumerate(_distribution):
                 dicts_to_plot.append({'Probability': float(_probability),
                                       'Category': _label,
-                                      'Topic': ' '.join(topic_keys[_topic_index][:5])})
+                                      'Topic': 'Topic ' + str(_topic_index).zfill(2) + ': ' + ' '.join(topic_keys[_topic_index][:5])})
 
     # Create a dataframe, format it for the heatmap function, and normalize the columns.
     df_to_plot = pd.DataFrame(dicts_to_plot)
@@ -182,8 +195,10 @@ def plot_categories_by_topics_heatmap(labels,
     if dim:
         plt.figure(figsize=dim)
     sns.set(style='ticks', font_scale=1.2)
-    sns.heatmap(df_norm_col, cmap=sns.cm.rocket_r)    
-    plt.xticks(rotation=45, ha='right')
+    ax = sns.heatmap(df_norm_col, cmap=sns.cm.rocket_r)    
+    ax.xaxis.tick_top()
+    ax.xaxis.set_label_position('top')
+    plt.xticks(rotation=30, ha='left')
     plt.tight_layout()
     if output_path:
         plt.savefig(output_path)
@@ -285,5 +300,5 @@ def plot_topics_over_time(topic_distributions, topic_keys, times, topic_index, o
     plt.show()
 
 
-def get_js_similarity(topic_index_1, topic_index_2, topic_distributions):
+def get_js_divergence(topic_index_1, topic_index_2, topic_distributions):
     return jensenshannon(topic_distributions[topic_index_1], topic_distributions[topic_index_2])
\ No newline at end of file
